#!/usr/bin/env bash
# Abort on Error
set -ev

export PING_SLEEP=30s
export WORKDIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"
export BUILD_OUTPUT=$WORKDIR/build.out

touch $BUILD_OUTPUT

dump_output() {
   echo Tailing the last 500 lines of output:
   tail -500 $BUILD_OUTPUT
}
error_handler() {
  echo ERROR: An error was encountered with the build.
  dump_output
  exit 1
}
# If an error occurs, run our error handler to output a tail of the build
trap 'error_handler' ERR

# Set up a repeating loop to send some output to Travis.

bash -c "while true; do echo \$(date) - building ...; sleep $PING_SLEEP; done" &
PING_LOOP_PID=$!


# Build and test using maven.

mvn clean -DskipTests=true -Dmaven.javadoc.skip=true -B -V install >> $BUILD_OUTPUT 2>&1 
cd hdfs && mvn test >> $BUILD_OUTPUT 2>&1
cd ../math && mvn test >> $BUILD_OUTPUT 2>&1
cd ../math-scala && mvn test >> $BUILD_OUTPUT 2>&1
cd ../spark && mvn test >> $BUILD_OUTPUT 2>&1
#cd ../flink && mvn test >> $BUILD_OUTPUT 2>&1
#cd ../h2o && mvn test >> $BUILD_OUTPUT 2>&1

# The build finished without returning an error so dump a tail of the output
dump_output

# nicely terminate the ping output loop
kill $PING_LOOP_PID

